@@ -17,7 +17,6 @@ def plot_rdm(rdm, rescale=False, conditions=None, con_fontsize=12, cmap=None):
     cons = rdm.shape[0]
 
     if cons == 2:
-
         print("The shape of RDM cannot be 2*2. Here NeuroRA cannot plot this RDM.")
 
         return None
@@ -25,12 +24,11 @@ def plot_rdm(rdm, rescale=False, conditions=None, con_fontsize=12, cmap=None):
     a, b = np.shape(rdm)
 
     if a != b:
-
         return None
 
     if rescale == True:
 
-        vrdm = np.reshape(rdm, [cons*cons])
+        vrdm = np.reshape(rdm, [cons * cons])
         svrdm = set(vrdm)
         lvrdm = list(svrdm)
         lvrdm.sort()
@@ -39,14 +37,14 @@ def plot_rdm(rdm, rescale=False, conditions=None, con_fontsize=12, cmap=None):
         for i in range(cons):
             for j in range(cons):
                 if i != j:
-                    rdm[i, j] = float((rdm[i, j]-minvalue)/(maxvalue-minvalue))
+                    rdm[i, j] = float((rdm[i, j] - minvalue) / (maxvalue - minvalue))
 
     if cmap == None:
         plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=plt.cm.jet, clim=(0, 1))
     else:
         plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=cmap, clim=(0, 1))
 
-    #plt.axis("off")
+    # plt.axis("off")
     cb = plt.colorbar()
     cb.ax.tick_params(labelsize=16)
     font = {'size': 18}
@@ -57,9 +55,9 @@ def plot_rdm(rdm, rescale=False, conditions=None, con_fontsize=12, cmap=None):
 
     if conditions != None:
         print("1")
-        step = float(1/cons)
-        x = np.arange(0.5*step, cons*step-0.5*step, step)
-        y = np.arange(cons*step-0.5*step, 0.5*step, -step)
+        step = float(1 / cons)
+        x = np.arange(0.5 * step, 1 + 0.5 * step, step)
+        y = np.arange(1 - 0.5 * step, -0.5 * step, -step)
         plt.xticks(x, conditions, fontsize=con_fontsize, rotation=30, ha="right")
         plt.yticks(y, conditions, fontsize=con_fontsize)
     else:
@@ -72,7 +70,6 @@ def plot_rdm_withvalue(rdm, value_fontsize=10, conditions=None, con_fontsize=12,
     cons = rdm.shape[0]
 
     if cons == 2:
-
         print("The shape of RDM cannot be 2*2. Here NeuroRA cannot plot this RDM.")
 
         return None
@@ -80,21 +77,14 @@ def plot_rdm_withvalue(rdm, value_fontsize=10, conditions=None, con_fontsize=12,
     a, b = np.shape(rdm)
 
     if a != b:
-
         return None
 
     if cmap == None:
-        plt.imshow(rdm, cmap=plt.cm.Greens, clim=(0, 1))
+        plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=plt.cm.Greens, clim=(0, 1))
     else:
-        plt.imshow(rdm, cmap=cmap, clim=(0, 1))
-
-    plt.axis("off")
-
-    for i in range(a):
-        for j in range(b):
-            text = plt.text(i, j, float('%.4f'%rdm[i, j]),
-                           ha="center", va="center", color="blue", fontsize=value_fontsize)
+        plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=cmap, clim=(0, 1))
 
+    # plt.axis("off")
     cb = plt.colorbar()
     cb.ax.tick_params(labelsize=16)
     font = {'size': 18}
@@ -102,14 +92,20 @@ def plot_rdm_withvalue(rdm, value_fontsize=10, conditions=None, con_fontsize=12,
 
     if conditions != None:
         print("1")
-        step = float(1/cons)
-        x = np.arange(0.5*step, cons*step-0.5*step, step)
-        y = np.arange(cons*step-0.5*step, 0.5*step, -step)
+        step = float(1 / cons)
+        x = np.arange(0.5 * step, 1 + 0.5 * step, step)
+        y = np.arange(1 - 0.5 * step, -0.5 * step, -step)
         plt.xticks(x, conditions, fontsize=con_fontsize, rotation=30, ha="right")
         plt.yticks(y, conditions, fontsize=con_fontsize)
     else:
         plt.axis("off")
 
+    for i in range(cons):
+        for j in range(cons):
+            print(i, j)
+            text = plt.text(i * step + 0.5 * step, 1 - j * step - 0.5 * step, float('%.4f' % rdm[i, j]),
+                            ha="center", va="center", color="blue", fontsize=value_fontsize)
+
     plt.show()
 
 def plot_corrs_by_time(corrs, labels=None, time_unit=[0, 0.1]):
@@ -382,112 +378,145 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
 
 def plot_brainrsa_regions(img, threshold=None, background=get_bg_ch2()):
 
-    if threshold != None:
+    imgarray = nib.load(img).get_data()
 
-        imgarray = nib.load(img).get_data()
-        affine = get_affine(img)
+    if (imgarray == np.nan).all() == True:
+        print("No Valid Results")
 
-        imgarray = correct_by_threshold(imgarray, threshold)
+    else:
+        if threshold != None:
 
-        img = nib.Nifti1Image(imgarray, affine)
+            imgarray = nib.load(img).get_data()
+            affine = get_affine(img)
 
-    plotting.plot_roi(roi_img=img, bg_img=background, threshold=0, vmin=0.1, vmax=1, title="Similarity", resampling_interpolation="continuous")
+            imgarray = correct_by_threshold(imgarray, threshold)
 
-    plt.show()
+            img = nib.Nifti1Image(imgarray, affine)
+
+        plotting.plot_roi(roi_img=img, bg_img=background, threshold=0, vmin=0.1, vmax=1, title="Similarity", resampling_interpolation="continuous")
+
+        plt.show()
 
 def plot_brainrsa_montage(img, threshold=None, slice=[6, 6, 6], background=get_bg_ch2bet()):
 
-    if threshold != None:
+    imgarray = nib.load(img).get_data()
 
-        imgarray = nib.load(img).get_data()
-        affine = get_affine(img)
+    if (imgarray == np.nan).all() == True:
 
-        imgarray = correct_by_threshold(imgarray, threshold)
+        print("No Valid Results")
 
-        img = nib.Nifti1Image(imgarray, affine)
+    else:
+        if threshold != None:
 
-    slice_x = slice[0]
-    slice_y = slice[1]
-    slice_z = slice[2]
+            imgarray = nib.load(img).get_data()
+            affine = get_affine(img)
 
-    if slice_x != 0:
-        plotting.plot_stat_map(stat_map_img=img, bg_img=background, display_mode='x', cut_coords=slice_x,
-                               title="Similarity -sagittal", draw_cross=True, vmax=1)
-    if slice_y != 0:
-        plotting.plot_stat_map(stat_map_img=img, bg_img=background, display_mode='y', cut_coords=slice_y,
-                               title="Similarity -coronal", draw_cross=True, vmax=1)
-    if slice_z != 0:
-        plotting.plot_stat_map(stat_map_img=img, bg_img=background, display_mode='z', cut_coords=slice_z,
-                               title="Similarity -axial", draw_cross=True, vmax=1)
+            imgarray = correct_by_threshold(imgarray, threshold)
 
-    return 0
+            img = nib.Nifti1Image(imgarray, affine)
+
+        slice_x = slice[0]
+        slice_y = slice[1]
+        slice_z = slice[2]
+
+        if slice_x != 0:
+            plotting.plot_stat_map(stat_map_img=img, bg_img=background, display_mode='x', cut_coords=slice_x,
+                                title="Similarity -sagittal", draw_cross=True, vmax=1)
+        if slice_y != 0:
+            plotting.plot_stat_map(stat_map_img=img, bg_img=background, display_mode='y', cut_coords=slice_y,
+                                title="Similarity -coronal", draw_cross=True, vmax=1)
+        if slice_z != 0:
+            plotting.plot_stat_map(stat_map_img=img, bg_img=background, display_mode='z', cut_coords=slice_z,
+                                title="Similarity -axial", draw_cross=True, vmax=1)
 
 def plot_brainrsa_glass(img, threshold=None):
 
-    if threshold != None:
+    imgarray = nib.load(img).get_data()
 
-        imgarray = nib.load(img).get_data()
-        affine = get_affine(img)
+    if (imgarray == np.nan).all() == True:
 
-        imgarray = correct_by_threshold(imgarray, threshold)
+        print("No Valid Results")
 
-        img = nib.Nifti1Image(imgarray, affine)
+    else:
+        if threshold != None:
 
-    plotting.plot_glass_brain(img, colorbar=True, title="Similarity", black_bg=True, draw_cross=True, vmax=1)
+            imgarray = nib.load(img).get_data()
+            affine = get_affine(img)
 
-    plt.show()
+            imgarray = correct_by_threshold(imgarray, threshold)
+
+            img = nib.Nifti1Image(imgarray, affine)
+
+        plotting.plot_glass_brain(img, colorbar=True, title="Similarity", black_bg=True, draw_cross=True, vmax=1)
+
+        plt.show()
 
 def plot_brainrsa_surface(img, threshold=None):
 
-    if threshold != None:
+    imgarray = nib.load(img).get_data()
 
-        imgarray = nib.load(img).get_data()
-        affine = get_affine(img)
+    if (imgarray == np.nan).all() == True:
 
-        imgarray = correct_by_threshold(imgarray, threshold)
+        print("No Valid Results")
 
-        img = nib.Nifti1Image(imgarray, affine)
+    else:
+        if threshold != None:
 
-    fsaverage = datasets.fetch_surf_fsaverage(mesh='fsaverage')
-    texture_left = surface.vol_to_surf(img, fsaverage.pial_left)
-    texture_right = surface.vol_to_surf(img, fsaverage.pial_right)
-    plotting.plot_surf_stat_map(fsaverage.pial_left, texture_left, hemi='left', threshold=0.1,
-                                bg_map=fsaverage.sulc_right, colorbar=True, vmax=1, darkness=0.7)
-    plotting.plot_surf_stat_map(fsaverage.pial_right, texture_right, hemi='right', threshold=0.1,
-                                bg_map=fsaverage.sulc_right, colorbar=True, vmax=1, darkness=0.7)
-    plotting.plot_surf_stat_map(fsaverage.pial_left, texture_right, hemi='right', threshold=0.1,
-                                bg_map=fsaverage.sulc_right, colorbar=True, vmax=1, darkness=0.7)
-    plotting.plot_surf_stat_map(fsaverage.pial_right, texture_left, hemi='left', threshold=0.1,
-                                bg_map=fsaverage.sulc_right, colorbar=True, vmax=1, darkness=0.7)
+            imgarray = nib.load(img).get_data()
+            affine = get_affine(img)
 
-    plt.show()
+            imgarray = correct_by_threshold(imgarray, threshold)
+
+            img = nib.Nifti1Image(imgarray, affine)
+
+        fsaverage = datasets.fetch_surf_fsaverage(mesh='fsaverage')
+        texture_left = surface.vol_to_surf(img, fsaverage.pial_left)
+        texture_right = surface.vol_to_surf(img, fsaverage.pial_right)
+        plotting.plot_surf_stat_map(fsaverage.pial_left, texture_left, hemi='left', threshold=0.1,
+                                    bg_map=fsaverage.sulc_right, colorbar=True, vmax=1, darkness=0.7)
+        plotting.plot_surf_stat_map(fsaverage.pial_right, texture_right, hemi='right', threshold=0.1,
+                                    bg_map=fsaverage.sulc_right, colorbar=True, vmax=1, darkness=0.7)
+        plotting.plot_surf_stat_map(fsaverage.pial_left, texture_right, hemi='right', threshold=0.1,
+                                    bg_map=fsaverage.sulc_right, colorbar=True, vmax=1, darkness=0.7)
+        plotting.plot_surf_stat_map(fsaverage.pial_right, texture_left, hemi='left', threshold=0.1,
+                                    bg_map=fsaverage.sulc_right, colorbar=True, vmax=1, darkness=0.7)
+
+        plt.show()
 
 def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None):
 
-    if threshold != None:
+    imgarray = nib.load(img).get_data()
 
-        imgarray = nib.load(img).get_data()
-        affine = get_affine(img)
+    if (imgarray == np.nan).all() == True:
 
-        imgarray = correct_by_threshold(imgarray, threshold)
-
-        img = nib.Nifti1Image(imgarray, affine)
-
-    if background == None:
-
-        plot_brainrsa_regions(img, threshold=threshold)
-
-        plot_brainrsa_montage(img, threshold=threshold, slice=slice)
-
-        plot_brainrsa_glass(img, threshold=threshold)
-
-        plot_brainrsa_surface(img, threshold=threshold)
+        print("No Valid Results")
 
     else:
 
-        plot_brainrsa_regions(img, threshold=threshold, background=background)
+        if threshold != None:
 
-        plot_brainrsa_montage(img, threshold=threshold, slice=slice, background=background)
+            imgarray = nib.load(img).get_data()
+            affine = get_affine(img)
 
-        plot_brainrsa_surface(img, threshold=threshold)
+            imgarray = correct_by_threshold(imgarray, threshold)
+
+            img = nib.Nifti1Image(imgarray, affine)
+
+        if background == None:
+
+            plot_brainrsa_regions(img, threshold=threshold)
+
+            plot_brainrsa_montage(img, threshold=threshold, slice=slice)
+
+            plot_brainrsa_glass(img, threshold=threshold)
+
+            plot_brainrsa_surface(img, threshold=threshold)
+
+        else:
+
+            plot_brainrsa_regions(img, threshold=threshold, background=background)
+
+            plot_brainrsa_montage(img, threshold=threshold, slice=slice, background=background)
+
+            plot_brainrsa_surface(img, threshold=threshold)
 
